@@ -77,8 +77,8 @@ def get_text(time: Union[datetime, str, int]):
         elif time.year != now.year:
             month_year = now.year - time.year
             if month_year:
-                _m = {1: "去年", -1: "明年"}
-                reply.append(_m.get(month_year, time.year))
+                _m = {1: "去", -1: "明"}
+                reply.append(f"{_m.get(month_year, time.year)}年")
             reply.append(f"{time.month}月")
             reply.append(f"{time.day}号")
         elif time.month != now.month:
@@ -90,9 +90,11 @@ def get_text(time: Union[datetime, str, int]):
         else:
             week_span = time.day - (now.day - now.weekday())
             if -7 <= week_span < 0:
-                reply.append(f"上周{week_span + 7 + 1}")
+                reply.append(f"上周{WEEK_DAY_DICT.get(week_span + 7 + 1)}")
             elif 7 <= week_span < 14:
-                reply.append(f"下周{ week_span - 7 + 1}")
+                reply.append(f"下周{WEEK_DAY_DICT.get(week_span - 7 + 1)}")
+            elif 0 <= week_span < 7:
+                reply.append(f"本周{WEEK_DAY_DICT.get(week_span + 1)}")
             else:
                 reply.append(f"{time.day}号")
     if 0 <= time.hour < 6:
@@ -114,7 +116,7 @@ def get_text(time: Union[datetime, str, int]):
 
 
 SECONDS_ONE_DAY = 60 * 60 * 24
-WEEK_DAY_DICT = {1: "一", 2: "二", 3: "三", 4: "四", 5: "五", 6: "日", 7: "天"}
+WEEK_DAY_DICT = {1: "一", 2: "二", 3: "三", 4: "四", 5: "五", 6: "六", 7: "日"}
 WEEK_DAY_STRS = "一二三四五六日天末"
 RE_WEEK = rf"(?<!这个)(?<!这|本)(?:周|星期)([\d{WEEK_DAY_STRS}])"
 TIME_FORMAT = "%Y-%m-%d %H:%M:%S"
